Um die Offenlegung sensibler Daten zu verhindern, müssen Entwickler zahlreiche, notwendige Best Practices der Branche im Einklang mit den aktuellen Vorschriften einhalten, um die Schwierigkeiten für Angreifer zu erhöhen.

- Die Entwickler müssen zunächst feststellen, welche Daten gemäß der Systemarchitektur und den gesetzlichen Vorschriften sensibel sind.
- Die Entwickler müssen sicherstellen, dass die Daten bei der Übertragung oder Speicherung verschlüsselt sind.
- Entwickler sollten Debugging- und Testfunktionen aus den Produktionsanwendungen und -systemen entfernen.
- Die Entwickler sollten die aufgelisteten Elemente überprüfen, um festzustellen, ob für jedes vorhandene Element eine gerechtfertigte geschäftliche Notwendigkeit besteht. Alle Elemente, die als unnötig erachtet werden, sollten entfernt werden.
- Die definierten Verfahren zur Erstellung von Anwendungen und Systemen sollten Schritte zur Entfernung von Dateien und Funktionen enthalten, die für den Einsatz in der Produktion nicht erforderlich sind, und die internen Sicherheitsprozesse und -kontrollen sollten bestätigen, dass dies vor der Produktionsfreigabe erfolgt ist.
